@@ -16,6 +16,7 @@
 import re
 from datetime import datetime, timezone
 from enum import Enum
+from functools import reduce
 from hashlib import sha1
 from itertools import zip_longest
 from typing import Any, Iterable, Optional, Tuple, TypeVar
@@ -424,16 +425,47 @@ class XsUri(serializable.helpers.BaseHelper):
 
     .. note::
         See XSD definition for xsd:anyURI: http://www.datypic.com/sc/xsd/t-xsd_anyURI.html
+        See JSON Schema definition for iri-reference: https://tools.ietf.org/html/rfc3987
     """
 
     _INVALID_URI_REGEX = re.compile(r'%(?![0-9A-F]{2})|#.*#', re.IGNORECASE + re.MULTILINE)
 
+    __SPEC_REPLACEMENTS = (
+        (' ', '%20'),
+        ('[', '%5B'),
+        (']', '%5D'),
+        ('<', '%3C'),
+        ('>', '%3E'),
+        ('{', '%7B'),
+        ('}', '%7D'),
+    )
+
+    @staticmethod
+    def __spec_replace(v: str, r: Tuple[str, str]) -> str:
+        return v.replace(*r)
+
+    @classmethod
+    def _spec_migrate(cls, o: str) -> str:
+        """
+         Make a string valid to
+         - XML::anyURI spec.
+         - JSON::iri-reference spec.
+
+         BEST EFFORT IMPLEMENTATION
+
+         @see http://www.w3.org/TR/xmlschema-2/#anyURI
+         @see http://www.datypic.com/sc/xsd/t-xsd_anyURI.html
+         @see https://datatracker.ietf.org/doc/html/rfc2396
+         @see https://datatracker.ietf.org/doc/html/rfc3987
+        """
+        return reduce(cls.__spec_replace, cls.__SPEC_REPLACEMENTS, o)
+
     def __init__(self, uri: str) -> None:
         if re.search(XsUri._INVALID_URI_REGEX, uri):
             raise InvalidUriException(
                 f"Supplied value '{uri}' does not appear to be a valid URI."
             )
-        self._uri = uri
+        self._uri = self._spec_migrate(uri)
 
     @property
     @serializable.json_name('.')
@@ -1211,38 +1243,41 @@ class Copyright:
         return f'<Copyright text={self.text}>'
 
 
-ThisTool = Tool(vendor='CycloneDX', name='cyclonedx-python-lib', version=__ThisToolVersion or 'UNKNOWN')
-ThisTool.external_references.update([
-    ExternalReference(
-        type=ExternalReferenceType.BUILD_SYSTEM,
-        url=XsUri('https://github.com/CycloneDX/cyclonedx-python-lib/actions')
-    ),
-    ExternalReference(
-        type=ExternalReferenceType.DISTRIBUTION,
-        url=XsUri('https://pypi.org/project/cyclonedx-python-lib/')
-    ),
-    ExternalReference(
-        type=ExternalReferenceType.DOCUMENTATION,
-        url=XsUri('https://cyclonedx.github.io/cyclonedx-python-lib/')
-    ),
-    ExternalReference(
-        type=ExternalReferenceType.ISSUE_TRACKER,
-        url=XsUri('https://github.com/CycloneDX/cyclonedx-python-lib/issues')
-    ),
-    ExternalReference(
-        type=ExternalReferenceType.LICENSE,
-        url=XsUri('https://github.com/CycloneDX/cyclonedx-python-lib/blob/main/LICENSE')
-    ),
-    ExternalReference(
-        type=ExternalReferenceType.RELEASE_NOTES,
-        url=XsUri('https://github.com/CycloneDX/cyclonedx-python-lib/blob/main/CHANGELOG.md')
-    ),
-    ExternalReference(
-        type=ExternalReferenceType.VCS,
-        url=XsUri('https://github.com/CycloneDX/cyclonedx-python-lib')
-    ),
-    ExternalReference(
-        type=ExternalReferenceType.WEBSITE,
-        url=XsUri('https://cyclonedx.org')
-    )
-])
+ThisTool = Tool(
+    vendor='CycloneDX',
+    name='cyclonedx-python-lib',
+    version=__ThisToolVersion or 'UNKNOWN',
+    external_references=[
+        ExternalReference(
+            type=ExternalReferenceType.BUILD_SYSTEM,
+            url=XsUri('https://github.com/CycloneDX/cyclonedx-python-lib/actions')
+        ),
+        ExternalReference(
+            type=ExternalReferenceType.DISTRIBUTION,
+            url=XsUri('https://pypi.org/project/cyclonedx-python-lib/')
+        ),
+        ExternalReference(
+            type=ExternalReferenceType.DOCUMENTATION,
+            url=XsUri('https://cyclonedx-python-library.readthedocs.io/')
+        ),
+        ExternalReference(
+            type=ExternalReferenceType.ISSUE_TRACKER,
+            url=XsUri('https://github.com/CycloneDX/cyclonedx-python-lib/issues')
+        ),
+        ExternalReference(
+            type=ExternalReferenceType.LICENSE,
+            url=XsUri('https://github.com/CycloneDX/cyclonedx-python-lib/blob/main/LICENSE')
+        ),
+        ExternalReference(
+            type=ExternalReferenceType.RELEASE_NOTES,
+            url=XsUri('https://github.com/CycloneDX/cyclonedx-python-lib/blob/main/CHANGELOG.md')
+        ),
+        ExternalReference(
+            type=ExternalReferenceType.VCS,
+            url=XsUri('https://github.com/CycloneDX/cyclonedx-python-lib')
+        ),
+        ExternalReference(
+            type=ExternalReferenceType.WEBSITE,
+            url=XsUri('https://github.com/CycloneDX/cyclonedx-python-lib/#readme')
+        )
+    ])
