@@ -19,7 +19,7 @@
 import warnings
 from datetime import datetime
 from itertools import chain
-from typing import TYPE_CHECKING, Iterable, Optional, Set, Union
+from typing import TYPE_CHECKING, Generator, Iterable, Optional, Union
 from uuid import UUID, uuid4
 
 import serializable
@@ -427,16 +427,11 @@ class Bom:
     def external_references(self, external_references: Iterable[ExternalReference]) -> None:
         self._external_references = SortedSet(external_references)
 
-    def _get_all_components(self) -> Set[Component]:
-        components: Set[Component] = set()
+    def _get_all_components(self) -> Generator[Component, None, None]:
         if self.metadata.component:
-            components.update(self.metadata.component.get_all_nested_components(include_self=True))
-
-        # Add Components and sub Components
+            yield from self.metadata.component.get_all_nested_components(include_self=True)
         for c in self.components:
-            components.update(c.get_all_nested_components(include_self=True))
-
-        return components
+            yield from c.get_all_nested_components(include_self=True)
 
     def get_vulnerabilities_for_bom_ref(self, bom_ref: BomRef) -> 'SortedSet[Vulnerability]':
         """
@@ -543,13 +538,13 @@ class Bom:
             self.register_dependency(target=_s)
 
         # 1. Make sure dependencies are all in this Bom.
-        all_bom_refs = set(map(lambda c: c.bom_ref, self._get_all_components())) | set(
+        component_bom_refs = set(map(lambda c: c.bom_ref, self._get_all_components())) | set(
             map(lambda s: s.bom_ref, self.services))
-        all_dependency_bom_refs = set(chain((d.ref for d in self.dependencies),
-                                            chain.from_iterable(
-                                                d.dependencies_as_bom_refs() for d in self.dependencies)))
-
-        dependency_diff = all_dependency_bom_refs - all_bom_refs
+        dependency_bom_refs = set(chain(
+            (d.ref for d in self.dependencies),
+            chain.from_iterable(d.dependencies_as_bom_refs() for d in self.dependencies)
+        ))
+        dependency_diff = dependency_bom_refs - component_bom_refs
         if len(dependency_diff) > 0:
             raise UnknownComponentDependencyException(
                 f'One or more Components have Dependency references to Components/Services that are not known in this '
