@@ -15,6 +15,8 @@
 # SPDX-License-Identifier: Apache-2.0
 # Copyright (c) OWASP Foundation. All Rights Reserved.
 
+
+import re
 from typing import Any, Callable
 from unittest import TestCase
 from unittest.mock import Mock, patch
@@ -29,7 +31,7 @@ from cyclonedx.output.json import BY_SCHEMA_VERSION, Json
 from cyclonedx.schema import OutputFormat, SchemaVersion
 from cyclonedx.validation.json import JsonStrictValidator
 from tests import SnapshotMixin, mksname, uuid_generator
-from tests._data.models import all_get_bom_funct_invalid, all_get_bom_funct_valid
+from tests._data.models import all_get_bom_funct_invalid, all_get_bom_funct_valid, bom_all_same_bomref
 
 UNSUPPORTED_SV = frozenset((SchemaVersion.V1_1, SchemaVersion.V1_0,))
 
@@ -80,6 +82,13 @@ class TestOutputJson(TestCase, SnapshotMixin):
             return None  # expected
         raise error.exception
 
+    def test_bomref_not_duplicate(self) -> None:
+        bom, nr_bomrefs = bom_all_same_bomref()
+        output = BY_SCHEMA_VERSION[SchemaVersion.V1_4](bom).output_as_string()
+        found = re.findall(r'"bom-ref":\s*"(.*?)"', output)
+        self.assertEqual(nr_bomrefs, len(found))
+        self.assertCountEqual(set(found), found, 'expected unique items')
+
 
 @ddt
 class TestFunctionalBySchemaVersion(TestCase):
